'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var apolloClient = require('apollo-client');
var React = _interopDefault(require('react'));
var reactApollo = require('react-apollo');

class Query extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.mapData = (result) => {
            const { loading, error, data } = result;
            if (loading) {
                return { type: 'loading' };
            }
            if (error) {
                return {
                    type: 'error',
                    error,
                };
            }
            if (data) {
                return {
                    type: 'data',
                    data,
                };
            }
            // This point should actually never be reached due to the restrictions of Apollo GraphQL responses
            console.error('An unexpected Query sidecase happened where no valid union type could be found, please file an issue for this.');
            return { type: 'error', error: new apolloClient.ApolloError({}) };
        };
    }
    render() {
        return (React.createElement(reactApollo.Query, Object.assign({}, this.props), data => this.props.children({ result: this.mapData(data) })));
    }
}

class Mutation extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.mapData = (result) => {
            const { loading, error, data } = result;
            if (loading) {
                return { type: 'loading' };
            }
            if (error) {
                return {
                    type: 'error',
                    error,
                };
            }
            if (data) {
                return {
                    type: 'data',
                    data,
                };
            }
            // This point should actually never be reached due to the restrictions of Apollo GraphQL responses
            console.error('An unexpected Mutation sidecase happened where no valid union type could be found, please file an issue for this.');
            return { type: 'error', error: new apolloClient.ApolloError({}) };
        };
    }
    render() {
        return (React.createElement(reactApollo.Mutation, Object.assign({}, this.props), (mutateFn, data) => this.props.children({ mutateFn, result: this.mapData(data) })));
    }
}

exports.Query = Query;
exports.Mutation = Mutation;
