import { ApolloError } from 'apollo-client';
import React from 'react';
import { Query, Mutation } from 'react-apollo';

class Query$1 extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.mapData = (result) => {
            const { loading, error, data } = result;
            if (loading) {
                return { type: 'loading' };
            }
            if (error) {
                return {
                    type: 'error',
                    error,
                };
            }
            if (data) {
                return {
                    type: 'data',
                    data,
                };
            }
            // This point should actually never be reached due to the restrictions of Apollo GraphQL responses
            console.error('An unexpected Query sidecase happened where no valid union type could be found, please file an issue for this.');
            return { type: 'error', error: new ApolloError({}) };
        };
    }
    render() {
        return (React.createElement(Query, Object.assign({}, this.props), data => this.props.children({ result: this.mapData(data) })));
    }
}

class Mutation$1 extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.mapData = (result) => {
            const { loading, error, data } = result;
            if (loading) {
                return { type: 'loading' };
            }
            if (error) {
                return {
                    type: 'error',
                    error,
                };
            }
            if (data) {
                return {
                    type: 'data',
                    data,
                };
            }
            // This point should actually never be reached due to the restrictions of Apollo GraphQL responses
            console.error('An unexpected Mutation sidecase happened where no valid union type could be found, please file an issue for this.');
            return { type: 'error', error: new ApolloError({}) };
        };
    }
    render() {
        return (React.createElement(Mutation, Object.assign({}, this.props), (mutateFn, data) => this.props.children({ mutateFn, result: this.mapData(data) })));
    }
}

export { Query$1 as Query, Mutation$1 as Mutation };
